#!/bin/sh
#######################################################
#
# flagchk.sh - check to see if the /etc/patchflag file
# has been set on every file in the pca_host_list file. 
#
# Author: Ron Halstead
# 
# Date: 08/17/08
#
# Description: Using encrypted private key for root
# use ssh to execute the ls command on every host 
# listed in the pca_host_type file.  
#
# Restrictions: This script must be run on the 
# host that generated the public key pair. The root
# public key must be place in root's .ssh directory
# in a file called "authorized_keys", on every host
# that is listed in the "pca_host_type" file. Of course
# you must be root on the host that owns the private
# key. 
#
# Caution: When generating a key pair Always use a 
# passphrase to encrypt the private key. The code 
# will prompt you for this passphrase once. 
#
####################################################### 
#
#set -x
#

# Are you root?
set `/usr/bin/id`
if [ $1 != "uid=0(root)" ]; then
        echo "$0: must be run as root"
        exit 1
fi

# Kill the ssh agent when the shell exits
trap '
        test -n "$SSH_AGENT_PID" && eval `ssh-agent -k` ;
        test -n "$SSH_AGENT_PID" && kill $SSH_AGENT_PID
' 0

# Check for a ssh agent identity
/bin/ssh-add -l > /dev/null
if [ $? -ne 0 ] ; then
        /bin/ssh-add
fi

for host in `cat /patches/pca/pca_host_type | awk '{ print $1 }'` ; do
        echo "$host \t\c"
        ssh  ${host} /bin/ls /etc/patchflag
        echo "Finished with ${host}"
done

exit 0

