#!/bin/sh
######################################################
#
# removeflag.sh - remove the /etc/patchflag file from
# each host in the "pca_host_type" file. 
#
# Author Ron Halstead
#
# Date: 08/18/08
# 
# Description: Using encrypted private key for root use
# ssh to execute the rm command on every host listed in 
# the "pca_host_type" file. 
#
# Restrictions: this script must be run on thr host that
# generated the public key pair for root. The root public 
# key must be placed in root's .ssh directory in a file 
# called "authorized_keys", on every host that is listed
# in the "pca_host_type" file. Of course you must be root on
# the host that owns the private key to run the script. 
#
# Caution: When generating a key pair ALWAYS use a 
# passphrase to encrypt the private key. The code will 
# prompt you for this passphrase once. 
#
########################################################
#
#set -x
# ssh to each host rm /etc/patchflag file
#

set `/usr/bin/id`
if [ $1 != "uid=0(root)" ]; then
        echo "$0: must be run as root"
        exit 1
fi

# Kill the ssh agent when the shell exits
trap '
        test -n "$SSH_AGENT_PID" && eval `ssh-agent -k` ;
        test -n "$SSH_AGENT_PID" && kill $SSH_AGENT_PID
' 0

# Check for a ssh agent identity
ssh-add -l > /dev/null
if [ $? -ne 0 ] ; then
        ssh-add
fi

for host in `cat /patches/pca/pca_host_type | awk '{ print $1 }'` ; do
	echo "$host \t\c" 
	ssh  ${host} 'rm /etc/patchflag'
	ssh  ${host} 'ls /etc/patchflag'
	echo "Finished with ${host}"
done

exit 0 
